﻿using Arction.WPF.LightningChartUltimate;
using Arction.WPF.LightningChartUltimate.Axes;
using Arction.WPF.LightningChartUltimate.SeriesXY;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            InitLightningChart(lc1);
            InitLightningChart(lc2);

            SeriesPoint[] points = new SeriesPoint[2500];

            for (int i = 0; i < points.Length; i++)
            {
                points[i] = new SeriesPoint(i * 0.1, Math.Sin(i)+5);
            }
            AddPointLineSeries(lc1);
            lc1.ViewXY.PointLineSeries[0].AddPoints(points, true);
        }

        private void InitLightningChart(LightningChartUltimate chart)
        {

            chart.ViewXY.AxisLayout.AutoAdjustMargins = false;


            chart.Title = new Arction.WPF.LightningChartUltimate.Titles.ChartTitle { Text = string.Empty };

            SetMargins(chart);

            chart.ChartRenderOptions.MultiCoreProcessing = MultiCoreProcessing.Off;
            chart.ChartRenderOptions.DeviceType = RendererDeviceType.HardwareOnly;
            chart.ChartRenderOptions.AntiAliasLevel = 2;
            chart.ChartRenderOptions.UpdateOnResizeTimeInterval = 500;

            chart.ViewXY.ZoomPanOptions.MouseWheelZooming = MouseWheelZooming.Horizontal;
            chart.ViewXY.ZoomPanOptions.PanDirection = PanDirection.Horizontal;
            chart.ViewXY.ZoomPanOptions.RectangleZoomDirectionLayered = RectangleZoomDirectionLayered.Horizontal;
            chart.ViewXY.PointLineSeries = new BindingList<PointLineSeries>();
            chart.ViewXY.LineCollections = new BindingList<LineCollection>();
            chart.ViewXY.ZoomPanOptions.RightToLeftZoomAction = RightToLeftZoomAction.RevertAxisRanges;
            chart.ViewXY.ZoomPanOptions.MouseWheelZooming = MouseWheelZooming.Off;

            chart.ViewXY.XAxes.Clear();
            chart.ViewXY.XAxes.Add(new Arction.WPF.LightningChartUltimate.Axes.AxisX(chart.ViewXY));
            SetXAxisValues(chart.ViewXY.XAxes[0], true);
            chart.ViewXY.LegendBox.Visible = false;

            chart.ViewXY.YAxes[0].RangeRevertMinimum = 0;
            chart.ViewXY.YAxes[0].RangeRevertMaximum = 10;
        }
        private void SetMargins(LightningChartUltimate chart)
        {
            double margin = 30;
            bool visible = chart == lc2;

            foreach (var item in chart.ViewXY.XAxes)
            {
                item.Visible = visible;
            }

            chart.ViewXY.Margins = new Thickness(margin, 15, 10, visible ? margin : 5);

        }
        private void SetXAxisValues(AxisX axisX, bool resetMinMax = false)
        {
            axisX.ScrollingGap = 0;
            axisX.SweepingGap = 0;

            if (resetMinMax)//Beim initialen Setzen sollen die Min/Max-Werte gesetzt werden, beim nachträglichen Konfigurieren jedoch nicht mehr
            {
                axisX.ScrollMode = XAxisScrollMode.Scrolling;
                axisX.Minimum = 0;
                axisX.Maximum = 100;
            }
            axisX.RangeRevertMinimum = 0;
            axisX.RangeRevertMaximum = 100;
            axisX.ValueType = AxisValueType.Number;
            axisX.RangeRevertEnabled = true;
            axisX.MouseScrolling = false;
            axisX.MouseScaling = false;
            axisX.AxisThickness = 1;
            axisX.AxisColor = Colors.Black;
            axisX.LabelsColor = Colors.Black;
            axisX.LabelsFont = new WPFFont("Arial", 12.0);
            axisX.Title = new Arction.WPF.LightningChartUltimate.Titles.AxisXTitle { Text = string.Empty, Visible = false };
        }

        private void AddPointLineSeries(LightningChartUltimate chart)
        {

            PointLineSeries pls;
            chart.BeginUpdate();


            pls = new PointLineSeries(chart.ViewXY, chart.ViewXY.XAxes[0], chart.ViewXY.YAxes[0]);

            pls.LimitYToStackSegment = true;
            pls.LineStyle = new LineStyle();
            pls.LineStyle.Color = Colors.Red;
            pls.Title = new Arction.WPF.LightningChartUltimate.Titles.SeriesTitle();
            pls.MouseHighlight = MouseOverHighlight.None;
            pls.MouseInteraction = false;
            pls.ScrollingStabilizing = false;


            chart.ViewXY.PointLineSeries.Add(pls);
            chart.EndUpdate();
        }
    }
}
